Fixed util/flag dependency
diff --git a/vendor/modules.txt b/vendor/modules.txt
index b7438be..cc42d42 100644
--- a/vendor/modules.txt
+++ b/vendor/modules.txt
@@ -249,8 +249,8 @@
 k8s.io/apimachinery/pkg/runtime
 k8s.io/apimachinery/pkg/runtime/schema
 k8s.io/apimachinery/pkg/util/intstr
-k8s.io/apimachinery/pkg/util/wait
 k8s.io/apimachinery/pkg/util/sets
+k8s.io/apimachinery/pkg/util/wait
 k8s.io/apimachinery/pkg/util/uuid
 k8s.io/apimachinery/pkg/conversion
 k8s.io/apimachinery/pkg/fields
@@ -550,8 +550,8 @@
 k8s.io/cloud-provider
 k8s.io/cloud-provider/service/helpers
 # k8s.io/component-base v0.0.0 => k8s.io/component-base v0.0.0-20190805141645-3a5e5ac800ae
-k8s.io/component-base/logs
 k8s.io/component-base/cli/flag
+k8s.io/component-base/logs
 k8s.io/component-base/cli/globalflag
 k8s.io/component-base/config
 k8s.io/component-base/featuregate
diff --git a/cmd/cloudstack-ccm/main.go b/cmd/cloudstack-ccm/main.go
index e851ba9..caf849d 100644
--- a/cmd/cloudstack-ccm/main.go
+++ b/cmd/cloudstack-ccm/main.go
@@ -24,7 +24,7 @@
 
 	"k8s.io/klog"
 
-	utilflag "k8s.io/apiserver/pkg/util/flag"
+	cliflag "k8s.io/component-base/cli/flag"
 	"k8s.io/component-base/logs"
 	"k8s.io/kubernetes/cmd/cloud-controller-manager/app"
 	_ "k8s.io/kubernetes/pkg/client/metrics/prometheus" // for client metric registration
@@ -41,11 +41,11 @@
 	command := app.NewCloudControllerManagerCommand()
 
 	// TODO: once we switch everything over to Cobra commands, we can go back to calling
 	// utilflag.InitFlags() (by removing its pflag.Parse() call). For now, we have to set the
 	// normalize func and add the go flag set by hand.
-	pflag.CommandLine.SetNormalizeFunc(utilflag.WordSepNormalizeFunc)
+	pflag.CommandLine.SetNormalizeFunc(cliflag.WordSepNormalizeFunc)
 	pflag.CommandLine.AddGoFlagSet(goflag.CommandLine)
-	//utilflag.InitFlags()
+	//cliflag.InitFlags()
 	logs.InitLogs()
 	defer logs.FlushLogs()
 
@@ -41,11 +41,11 @@
 
 	// TODO: once we switch everything over to Cobra commands, we can go back to calling
-	// utilflag.InitFlags() (by removing its pflag.Parse() call). For now, we have to set the
+	// cliflag.InitFlags() (by removing its pflag.Parse() call). For now, we have to set the
 	// normalize func and add the go flag set by hand.